Command Line Tool to import dashboards
======================================

Use putrefdata.py to insert dashboard templates to pulse_imports reference table. Setup instructions and usage examples can be found below.
```
Usage: putrefdata.py -u <username> -d <directory> [-q <IP address>] [-p <password>] [-c] [-x <proxy>]
    -u, QRadar username (must have admin role)
    -d, directory containing dashboard templates
    -q, QRadar IP address (defaults to 127.0.0.1)
    -p, QRadar user password (prompted if not provided)
    -c, clears the reference table before inserting
    -x, proxy to use for http requests, e.g. socks5h://localhost:1080'
```



## Steps to execute in isolated environment

### MacOS / Linux
* Clone or download and unzip the project.

* cd into the directory containing putrefdata.py
```
cd reference-table-import
```

* Install virtualenv
```
sudo /usr/bin/easy_install virtualenv
```

* Create a virtual environment
```
virtualenv venv
```

* Activate venv
```
source venv/bin/activate
```

* Install dependencies
```
pip install -r requirements.txt
```

NOTE: If you need a proxy to access QRadar, such as a bastion host, add the `-x` option to the putrefdata.py invocations below. e.g. `-x socks5h://localhost:1080`

* To insert dasboards found in a directory into pulse_imports table: 
```     
putrefdata.py -u admin -d User/Desktop/dashboards -q 127.0.0.1
``` 
* Or add `-c` option to delete the content of the pulse_imports table first and then insert dasboards found in the given directory:
```
putrefdata.py -u admin -d User/Desktop/dashboards -q 127.0.0.1 -c
```

* Deactivate venv
```
deactivate
```

## Windows

* Clone or download and unzip the project.

* Make sure that the path to the `<path to python install>\Scripts` directory is included in the system path env. variable  

* Open a command line window.

* cd into directory containing putrefdata.py
```
cd User/Desktop/reference-table-import
```

* Install virtualenv
```
pip install virtualenv
```

* Create a virtual environment
```
virtualenv venv
```

* Activate venv
```
venv\Scripts\activate.bat
```

* Install requirements
```
pip install -r requirements.txt
```
NOTE: If you need a proxy to access QRadar, such as a bastion host, add the `-x` option to the putrefdata.py invocations below. e.g. `-x socks5h://localhost:1080`

To insert dasboards found a the directory into pulse_imports table 
```     
putrefdata.py -u "admin" -d "C:\dashboards" -q 127.0.0.1
```
Or add `-c` option to delete the content of the pulse_imports table first and then insert dasboards found
in the given directory 
``` 
putrefdata.py -u "admin" -d "C:\dashboards" -q 127.0.0.1 -c
```

* Deactivate venv
```
deactivate
```

## Creating a content pack in QRadar

After the you pushed the dashboards to reference data, you can export them as a content pack running the following command on the QRadar host:
```
/opt/qradar/bin/contentManagement.pl --action export --content-type referencedata --regex "pulse_imports" --include-reference-data-elements
```

## Troubleshooting

If when running `virtualenv env` command, you get "setuptools pip wheel failed with error code 1". Try it with specifying python version: 
```
virtualenv -p /usr/bin/python2.7 venv
```
